
### Rarefraction curves

The x-axis of the plot shows the total number of sampled sequences, and the y-axis shows the total number of unique sequences.

The plot can be interpreted as follows:

- Samples with higher sequencing depth will have more unique sequences at each point on the x-axis.
- Samples with lower sequencing depth will have fewer unique sequences at each point on the x-axis.

This plot is useful for NGS because it can be used to assess the quality of the sequencing data and to determine whether the sequencing depth is sufficient for the desired application. For example, if you are trying to identify rare variants in a sample, you will need to have a high sequencing depth in order to be confident that the variants are real and not simply sequencing errors.

Here are some specific examples of how the plot could be used to interpret NGS data:

1. If you are comparing two samples with different sequencing depths, you can use the plot to see which sample has more unique sequences at each point on the x-axis. This can help you to determine which sample is more likely to contain the variants of interest.
2. If you are trying to determine whether the sequencing depth of a sample is sufficient for a particular application, you can use the plot to compare the sample to other samples that have been used successfully for the same application.
3. If you are seeing a plateau in the number of unique sequences as the sequencing depth increases, this may indicate that you have reached a saturation point and that further sequencing will not yield much new information.